==> haskell-hspec-2.10.9-118.6-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec
version:              2.10.9
visibility:           public
id:                   hspec-2.10.9-KuS4B4SgPwm179O4lsuAOc
key:                  hspec-2.10.9-KuS4B4SgPwm179O4lsuAOc
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    Hspec is a testing framework for Haskell.  Some of Hspec'\''s distinctive
    features are:

    * a friendly DSL for defining tests

    * integration with QuickCheck, SmallCheck, and HUnit

    * parallel test execution

    * automatic discovery of test files

    The Hspec Manual is at <https://hspec.github.io/>.

category:             Testing
abi:                  38b27bccf23a0e324d42368938ca1c3e
exposed:              True
exposed-modules:
    Test.Hspec Test.Hspec.Discover Test.Hspec.Formatters
    Test.Hspec.QuickCheck Test.Hspec.Runner

hidden-modules:       Paths_hspec
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hspec-2.10.9
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hspec-2.10.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec
hs-libraries:         HShspec-2.10.9-KuS4B4SgPwm179O4lsuAOc
depends:
    QuickCheck-2.14.3-AB831W8sF74KL3cz7DxP1X base-4.16.4.0
    hspec-core-2.10.9-EPbsf4CX1VNHe1gcsgpM0I
    hspec-discover-2.10.9-5Raukkb2PEP7FOCSGQ7nrF
    hspec-expectations-0.8.3-53KTMpuZLbD4EdixkL29oj

haddock-interfaces:   /usr/share/doc/haskell-hspec/html/hspec.haddock
haddock-html:         /usr/share/doc/haskell-hspec/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-2.10.9-229.7-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec
version:              2.10.9
visibility:           public
id:                   hspec-2.10.9-8PqvxiZVgrL4DvXVyNhtnS
key:                  hspec-2.10.9-8PqvxiZVgrL4DvXVyNhtnS
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    Hspec is a testing framework for Haskell.  Some of Hspec'\''s distinctive
    features are:

    * a friendly DSL for defining tests

    * integration with QuickCheck, SmallCheck, and HUnit

    * parallel test execution

    * automatic discovery of test files

    The Hspec Manual is at <https://hspec.github.io/>.

category:             Testing
abi:                  91bd9475bc75284dec350b7517e5bb2b
exposed:              True
exposed-modules:
    Test.Hspec Test.Hspec.Discover Test.Hspec.Formatters
    Test.Hspec.QuickCheck Test.Hspec.Runner

hidden-modules:       Paths_hspec
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-2.10.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-2.10.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-2.10.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec
hs-libraries:         HShspec-2.10.9-8PqvxiZVgrL4DvXVyNhtnS
depends:
    QuickCheck-2.14.3-Gpw9UoHUxB71c0Trj8n39O base-4.17.2.1
    hspec-core-2.10.9-JXA91YXBxjG5KLMnkMduaR
    hspec-discover-2.10.9-Ie94BTvw45L7TzOs6vgnWx
    hspec-expectations-0.8.3-8SHeV75XzHGAS0nDpIhPfV

haddock-interfaces:   /usr/share/doc/haskell-hspec/html/hspec.haddock
haddock-html:         /usr/share/doc/haskell-hspec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
